
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '35.0.0rc1',
    'branch_nick': 'master',
    'revision_id': '4bf531881e5f5f44c3d84cc2b11afc68ed56578a',
    'revno': 13072
}
